/*
Copyright (c) 2018-2019 Uber Technologies, Inc.

This source code is licensed under the MIT license found in the
LICENSE file in the root directory of this source tree.
*/
import * as React from 'react';
import CellShell from './cell-shell.js';
import { COLUMNS } from './constants.js';
import { HighlightCellText } from './text-search.js';

function StringFilter(props) {
  return React.createElement("div", null, "not implemented for string column");
}

var StringCell = React.forwardRef(function (props, ref) {
  return React.createElement(CellShell, {
    ref: ref,
    isMeasured: props.isMeasured,
    isSelected: props.isSelected,
    onSelect: props.onSelect
  }, props.textQuery ? React.createElement(HighlightCellText, {
    text: props.value,
    query: props.textQuery
  }) : props.value);
});
StringCell.displayName = 'StringCell';

function StringColumn(options) {
  return {
    kind: COLUMNS.STRING,
    title: options.title,
    sortable: options.sortable === undefined ? true : options.sortable,
    filterable: false,
    renderCell: StringCell,
    renderFilter: StringFilter,
    buildFilter: function buildFilter(params) {
      return function (data) {
        return true;
      };
    },
    sortFn: function sortFn(a, b) {
      return a.localeCompare(b);
    },
    minWidth: options.minWidth
  };
}

export default StringColumn;